@@ -7,6 +7,7 @@
 
 class Options;
 class GPGHandler;
+class PGPSection;
 
 #include <bobcat/tempstream>
 
@@ -28,11 +29,11 @@ class Decryptor
 
     private:
         void clearFiles() const;
+        void decrypt(PGPSection const &pgpSection) const;
 
         void setVerbose();
 
-        static void error(int ret, 
-                          std::pair<unsigned, unsigned> const &range);
+        static void error(int ret, std::string const &msg);
 };
 
 #endif
