@@ -13,6 +13,7 @@ extern std::ostream *g_verbose;
 
 std::string fileInfo();
 std::istream &nextline(std::istream &in, std::string &line);
-void  starred(std::ostream &out, std::string const &msg);
+void  starred(std::string const &msg);
+void showDots();
 
 #endif
