@@ -3,7 +3,10 @@
 istream &nextline(istream &in, string &line)
 {
     if (getline(in, line))
+    {
         ++g_lineNr;
+        (*g_dots)();
+    }
 
     return in;
 }
