@@ -10,19 +10,18 @@ class Options;
 
 class GPGHandler: public FBB::Fork
 {
-    std::ostream &d_out;
-
     Options const &d_options;
-    std::istream *d_in;
 
-    bool d_checkPassphrase;
-    bool d_passphraseFirstLine;
+    std::ostream *d_messages;
 
-    std::string d_gpgCommand;
+    bool d_passphraseRead;                  // passphrase read from file
     std::string d_passphrase;
 
-    FBB::Pipe d_childInput;
-    FBB::Pipe d_childOutput;
+    std::string d_gpgCommand;
+    std::string d_filename;
+    std::string d_decryptedName;            // filename of the file to receive
+                                            // the decrypted info
+
     FBB::Pipe d_childMessages;
 
     int d_ret;                              // return value of the gpg call
@@ -30,21 +29,19 @@ class GPGHandler: public FBB::Fork
     static unsigned s_nRetries;             // # times a pwd was requested
 
     public:
-                                            // passphrase may have been 
-                                            // provided via the 1st input line
-        GPGHandler(std::ostream &out, bool passphraseFirstLine);  
-        ~GPGHandler() override;             // closes the pipes
+        GPGHandler();  
 
-        void checkPassphrase(std::istream &in);
+        void setDecryptedName(std::string const &filename);
 
-        int process(std::istream &in);
+        int process(std::string const &filename);
+
+        void getPassphrase(size_t attempt); // get the passphrase (/dev/tty
+                                            // or from file)
 
     private:
         std::string passphraseFd(FBB::Pipe &pipe) const;
 
-        bool getPassphrase();           // get the passphrase from /dev/tty
-        void retryPassphrase();
-        void resetPipes();
+        void resetPipe();
 
         void childRedirections() override;
         void childProcess()      override;
@@ -53,5 +50,18 @@ class GPGHandler: public FBB::Fork
         static int echo(struct termios *ttySaved, bool reset = false);
 };
      
-//    
+inline void GPGHandler::setDecryptedName(std::string const &filename)
+{
+    d_decryptedName = filename;
+}
+    
 #endif
+
+
+
+
+
+
+
+
+
