@@ -15,9 +15,6 @@ class Guncat
 {
     Options const &d_options;
 
-    std::unique_ptr<std::ostream> d_ofstream;
-    std::ostream &d_out;
-        
     bool d_gpgCommand;
     bool d_pgpRanges;
     bool d_passphraseFirstLine;                       // handled in process()
@@ -43,9 +40,6 @@ class Guncat
         void programArguments();
 
         bool reduceHeaders(std::string const &line);
-
-        static std::ostream *outputStream(Options const &options);
-
 };
         
 #endif
