@@ -13,7 +13,7 @@ void Guncat::process(istream &in)
     {
         if (line == g_beginPGP)
         {
-            d_decryptor.handlePGP(in, d_out);
+            d_decryptor.process(in);    // , d_out);
             continue;
         }
 
@@ -26,10 +26,10 @@ void Guncat::process(istream &in)
         if (reduce)
             reduce = reduceHeaders(line);
         else
-            d_out << line << '\n';
+            cout << line << '\n';
     }
 
-    d_out.flush();
+    cout.flush();
 }
 
 
