@@ -15,7 +15,7 @@ bool Guncat::reduceHeaders(string const &line)
         ) 
         != s_acceptEnd
     )
-        d_out << line << '\n';
+        cout << line << '\n';
 
     return true;
 }
