@@ -3,6 +3,7 @@
 
 #include <string>
 #include <fstream>
+#include <memory>
 
 namespace FBB
 {
@@ -27,8 +28,8 @@ class Options
     std::string d_verbose;
 
     size_t d_timeLimit;
-                                                    // a file by name to 
-    std::ofstream d_msg;                            // receive GPG messages
+                                                    // a file by name 
+    std::unique_ptr<std::ofstream> d_msgPtr;        // receiving GPG messages
 
     std::ostream *d_gpgMessages;                    // a pointer to the used
                                                     // messages stream
