@@ -13,7 +13,9 @@ void Options::setGpgMessages()
         d_gpgMessages = &cerr;
     else
     {
-        d_msg = Exception::factory<ofstream>(filename);
-        d_gpgMessages = &d_msg;
+        d_msgPtr.reset(
+                    new ofstream{ Exception::factory<ofstream>(filename) }
+                 );
+        d_gpgMessages = d_msgPtr.get();
     }
 }
