@@ -1,5 +1,6 @@
 #include <bobcat/arg>
 
+using namespace std;
 using namespace FBB;
 
 // initializing FBB::Arg is separated from main() so it can be used by
@@ -12,11 +13,11 @@ namespace
     Arg::LongOption longOptions[] =
     {
         Arg::LongOption("dots",             'd'),
-        Arg::LongOption("gpg-command",      Arg::None),
+        Arg::LongOption("gpg-command",      Arg::NoArg),
         Arg::LongOption("gpg-option",       Arg::Required),
         Arg::LongOption("gpg-path",         Arg::Required),
         Arg::LongOption("help",             'h'),
-        Arg::LongOption("no-errors",        Arg::None),
+        Arg::LongOption("no-errors",        Arg::NoArg),
         Arg::LongOption("passphrase",       Arg::Required),
         Arg::LongOption("pgp-messages",     'm'),
         Arg::LongOption("pgp-ranges",       'r'),
@@ -26,15 +27,14 @@ namespace
         Arg::LongOption("skip-incomplete",  's'), 
         Arg::LongOption("time-limit",       'T'),
         Arg::LongOption("tty-OK",           't'),
-        Arg::LongOption("verbose",          'V'),
+        Arg::LongOption("verbose",          'V'),   // optional argument
         Arg::LongOption("version",          'v'),
+        Arg::LongOption("write",            'w'),
     };
-
-    auto longEnd = longOptions + std::size(longOptions);
 }
 
 Arg const &prepareArgs(int argc, char **argv)
 {
-    return Arg::initialize("dhm:qRrsStT:vV:",
-                           longOptions, longEnd, argc, argv);
+    return Arg::initialize("dhm:qRrsStT:vV::w:",
+                           longOptions, end(longOptions), argc, argv);
 }
