@@ -40,10 +40,11 @@ namespace
                   decrypting an encrypted section (by default: no time limit
                   is used).
       --tty-OK (-t): by default gpg's option --no-tty is used.
-      --verbose (-V) path: specify - to write additional messages to stderr,
-                  otherwise messages are written to `path' (by default
-                  messages are suppressed).
-      --version (-v)   - show version information (ends guncat, returning 0).
+      --verbose (-V) - write extra messages to stderr. Use `--verbose=path' or
+                  `-Vpath' to write extra messages to the file `path'.
+      --version (-v)    - show version information (ends guncat, returning 0).
+      --write (-w) path - path of the file to receive the output. By default
+                  cout is used.
 
    [file(s)] - file(s) to process. Standard input redirection can also be
                   used. By default the processed information is written to the
